@@ -269,15 +269,15 @@ setMethod("clv.model.expectation", signature(clv.model="clv.model.pnbd.no.cov"),
 
 
 
-# . clv.model.predict.new.customer.unconditional.expectation --------------------------------------------------------------------------------------------------------
-setMethod("clv.model.predict.new.customer.unconditional.expectation", signature = signature(clv.model="clv.model.pnbd.no.cov"), definition = function(clv.model, clv.fitted, clv.newcustomer, t){
+# . clv.model.predict.new.customer --------------------------------------------------------------------------------------------------------
+setMethod("clv.model.predict.new.customer", signature = signature(clv.model="clv.model.pnbd.no.cov"), definition = function(clv.model, clv.fitted, clv.newcustomer){
 
   return(pnbd_nocov_expectation(
       r = clv.fitted@prediction.params.model[["r"]],
       s = clv.fitted@prediction.params.model[["s"]],
       alpha_0 = clv.fitted@prediction.params.model[["alpha"]],
       beta_0 = clv.fitted@prediction.params.model[["beta"]],
-      vT_i = t))
+      vT_i = clv.newcustomer@num.periods))
 })
 
 
