@@ -91,11 +91,10 @@ setMethod(f = "clv.controlflow.predict.new.customer", signature = signature(clv.
 
   check_err_msg(check_user_data_predict_newcustomer_staticcov(clv.fitted=clv.fitted, clv.newcustomer=clv.newcustomer))
 
-  return(drop(clv.model.predict.new.customer.unconditional.expectation(
+  return(drop(clv.model.predict.new.customer(
     clv.model = clv.fitted@clv.model,
     clv.fitted = clv.fitted,
-    clv.newcustomer=clv.newcustomer,
-    t=clv.newcustomer@num.periods)))
+    clv.newcustomer=clv.newcustomer)))
 })
 
 
