@@ -2,15 +2,25 @@
 #' @title New customer prediction data
 #'
 #' @description
-#' The methods documented here are to be used together with \link[CLVTools:predict.clv.fitted.transactions]{predict} to obtain
-#' the expected number of transactions of an average newly alive customer.
-#' It describes the number of transactions a single, average new customer is expected to make in
-#' the \code{num.periods} periods since making the first transaction ("coming alive"). This prediction is only
-#' sensible for customers who just came alive and have not had the chance to reveal any more of their behavior.
+#' The methods documented here are to be used together with
+#' \link[CLVTools:predict.clv.fitted.transactions]{predict (transactions)} to obtain
+#' the expected number of transactions of an average newly alive customer and
+#' with \link[CLVTools:predict.clv.fitted.spending]{predict (spending)} to obtain
+#' the expected spending of an average newly alive customer.
+#' This prediction is only sensible for (fictional) customers without order history:
+#' Customers which just came alive and have not had the chance to reveal any more of their behavior.
 #'
-#' The data required for this new customer prediction is produced by the methods described here. This is mostly covariate data
-#' for static and dynamic covariate models. See details for the required format.
+#' The methods described here produce the data required as input to
+#' \code{predict(newdata=)} to make this new customer prediction.
+#' This is mostly covariate data for static and dynamic covariate models.
+#' See details for the required format.
 #'
+#' \code{newcustomer()}, \code{newcustomer.static()}, \code{newcustomer.dynamic()}:
+#' To predict the number of transactions a single, fictional, average new customer is expected to make in
+#' the \code{num.periods} periods since making the first transaction ("coming alive").
+#'
+#' \code{newcustomer.spending()}: To estimate how much a single, fictional, average
+#' new customer is expected to spend on average per transaction.
 #'
 #' @param num.periods A positive, numeric scalar indicating the number of periods to predict.
 #' @param data.cov.life Numeric-only covariate data for the lifetime process for a single customer, \code{data.table} or \code{data.frame}. See details.
@@ -18,7 +28,8 @@
 #' @param first.transaction For dynamic covariate models only: The time point of the first transaction of the customer ("coming alive") for which a prediction is made.
 #' Has to be within the time range of the covariate data.
 #'
-#' @seealso \link[CLVTools:predict.clv.fitted.transactions]{predict} to use the output of the methods described here.
+#' @seealso \link[CLVTools:predict.clv.fitted.transactions]{predict (transactions)} to use the output of the methods described here.
+#' @seealso \link[CLVTools:predict.clv.fitted.spending]{predict (spending)} to use the output of the methods described here.
 #'
 #' @details
 #' The covariate data has to contain one column for every covariate parameter in the fitted model. Only numeric values are allowed, no factors or characters.
@@ -45,6 +56,9 @@
 #' \item{newcustomer()}{An object of class \code{clv.newcustomer.no.cov}}
 #' \item{newcustomer.static()}{An object of class \code{clv.newcustomer.static.cov}}
 #' \item{newcustomer.dynamic()}{An object of class \code{clv.newcustomer.dynamic.cov}}
+#' \item{newcustomer.spending()}{An object of class \code{clv.newcustomer.spending}}
+#'
+#'
 #'
 #' @examples
 #' \donttest{
@@ -81,6 +95,11 @@
 #' )
 #'
 #'
+#' # Spending model
+#' gg.apparel <- gg(clv.data.apparel)
+#' predict(gg.apparel, newdata = newcustomer.spending())
+#'
+#'
 #'
 #' # Static covariate model
 #' p.apparel.static <- pnbd(clv.data.static.cov)
@@ -127,16 +146,28 @@
 #'     first.transaction = "2051-02-16"
 #'   )
 #' )
-#'
 #' }
 #' }
 #'
 NULL
 
+# . clv.newcustomer.base -------------------------------------------------------
+# A (near useless) base class from which other 'newcustomer' classes inherit.
+# This is required because a class defined without slots and without parents is
+# considered VIRTUAL and cannot be instantiated. Inheriting from this class,
+# allows to define a class `newcustomer.spending` which has no slots and
+# otherwise would be considered VIRTUAL.
+# This base class additionally is handy to catch any type of newcustomer
+# instance when verifying parameters.
+# Making this class virtual is not required as having no slots and parent has
+# the same effect but better to be explicit.
+setClass("clv.newcustomer.base", contains = "VIRTUAL")
+
 setClass(
   Class = "clv.newcustomer.no.cov",
-  representation = list(num.periods="numeric")
-  )
+  representation = list(num.periods="numeric"),
+  contains = 'clv.newcustomer.base'
+)
 
 clv.newcustomer.no.cov <- function(num.periods){
   return(new("clv.newcustomer.no.cov", num.periods=num.periods))
@@ -152,8 +183,9 @@ clv.newcustomer.no.cov <- function(num.periods){
 # convert the data
 setClass(
   Class = "clv.newcustomer.static.cov",
-  contains = "clv.newcustomer.no.cov",
+  contains = "clv.newcustomer.base",
   representation = list(
+    num.periods="numeric",
     data.cov.life="data.table",
     data.cov.trans="data.table"
 ))
@@ -181,8 +213,11 @@ clv.newcustomer.static.get.matrix.cov.life <- function(clv.newcustomer, clv.fitt
 
 setClass(
   Class = "clv.newcustomer.dynamic.cov",
-  contains = "clv.newcustomer.static.cov",
+  contains = "clv.newcustomer.base",
   representation = list(
+    num.periods="numeric",
+    data.cov.life="data.table",
+    data.cov.trans="data.table",
     # Has to be ANY because can be Date, Posixt, or character because this class is
     # used to transport the data to the clv.fitted object for predicting and it
     # contains the clv.data@clv.time object required to convert first.transaction
@@ -229,6 +264,19 @@ clv.newcustomer.dynamic.cov.convert.time <- function(clv.newcustomer, clv.time){
 }
 
 
+# Needs to inherit from a class as it would otherwise be a VIRTUAL class as it
+# also has no slots.
+setClass(
+  Class = "clv.newcustomer.spending",
+  contains = 'clv.newcustomer.base'
+)
+
+clv.newcustomer.spending <- function(){
+  return(new("clv.newcustomer.spending"))
+}
+
+
+
 #' @rdname newcustomer
 #' @export
 newcustomer <- function(num.periods){
@@ -279,6 +327,13 @@ newcustomer.dynamic <- function(num.periods, data.cov.life, data.cov.trans, firs
 }
 
 
+#' @rdname newcustomer
+#' @export
+newcustomer.spending <- function(){
+  return(clv.newcustomer.spending())
+}
+
+
 
 check_user_data_newcustomer_staticcovdatacov <- function(data.cov, name.of.covariate){
   # Check if data has basic properties
