@@ -1,13 +1,11 @@
 # Load data ---------------------------------------------------------------------------------------
-data("apparelTrans")
 data("apparelStaticCov")
 
 
 
 # Parameter clv.data ---------------------------------------------------------------------------------------
-expect_silent(clv.data.apparel.nohold   <- clvdata(apparelTrans, date.format = "ymd", time.unit = "w"))
-expect_silent(clv.data.apparel.withhold <- clvdata(apparelTrans, date.format = "ymd", time.unit = "w",
-                                                   estimation.split = 39))
+clv.data.apparel.nohold <- fct.helper.create.clvdata.apparel.nocov(estimation.split = NULL)
+clv.data.apparel.withhold <- fct.helper.create.clvdata.apparel.nocov()
 
 
 test_that("Works with and withouth holdout period", {
